@@ -38,22 +38,18 @@ a code security process, and false positives could be highly dangerous.
 
 =cut
 
-use strict;
-use overload 'bool' => sub () { 1 },
-             '=='   => 'equal';
-use Params::Util '_INSTANCE',
-                 '_ARRAY';
-
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.203';
-}
-
 # For convenience (and since this isn't really a public class), import
 # the methods we will need from Scalar::Util.
-use Scalar::Util 'refaddr',
-                 'reftype',
-                 'blessed';
+use strict;
+use Scalar::Util qw{refaddr reftype blessed};
+use Params::Util qw{_INSTANCE _ARRAY};
+use PPI::Util    ();
+
+our $VERSION = '1.279';
+
+use overload 'bool' => \&PPI::Util::TRUE;
+use overload '=='   => 'equal';
+
 
 
 
@@ -79,7 +75,7 @@ sub new {
 
 	# Check the required params
 	my $Document  = _INSTANCE($args{Document}, 'PPI::Document') or return undef;
-	my $version   = $args{version} or return undef;
+	my $version   = $args{version};
 	my $functions = _ARRAY($args{functions}) or return undef;
 
 	# Create the object
@@ -154,7 +150,9 @@ sub equal {
 	return undef if $self->{processing};
 
 	# Check the version and function list first
-	return '' unless $self->version eq $other->version;
+	my $v1 = $self->version || "undef";
+	my $v2 = $other->version || "undef";
+	return '' if $v1 ne $v2;
 	$self->_equal_ARRAY( $self->functions, $other->functions ) or return '';
 
 	# Do the main comparison run
@@ -305,7 +303,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 Adam Kennedy.
+Copyright 2005 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
