@@ -25,12 +25,11 @@ use strict;
 use Clone 0.30      ();
 use Scalar::Util    qw{refaddr};
 use Params::Util    qw{_INSTANCE _ARRAY};
-use List::Util      ();
 use PPI::Util       ();
 use PPI::Node       ();
-use PPI::Singletons '%_PARENT';
+use PPI::Singletons '%_PARENT', '%_POSITION_CACHE';
 
-our $VERSION = '1.271'; # VERSION
+our $VERSION = '1.279';
 
 our $errstr = "";
 
@@ -256,12 +255,10 @@ immediately after the current one, or false if there is no next sibling.
 
 sub next_sibling {
 	my $self     = shift;
-	my $parent   = $_PARENT{refaddr $self} or return '';
 	my $key      = refaddr $self;
+	my $parent   = $_PARENT{$key} or return '';
 	my $elements = $parent->{children};
-	my $position = List::Util::first {
-		refaddr $elements->[$_] == $key
-		} 0..$#$elements;
+	my $position = $parent->__position($self);
 	$elements->[$position + 1] || '';
 }
 
@@ -279,12 +276,10 @@ sibling.
 
 sub snext_sibling {
 	my $self     = shift;
-	my $parent   = $_PARENT{refaddr $self} or return '';
 	my $key      = refaddr $self;
+	my $parent   = $_PARENT{$key} or return '';
 	my $elements = $parent->{children};
-	my $position = List::Util::first {
-		refaddr $elements->[$_] == $key
-		} 0..$#$elements;
+	my $position = $parent->__position($self);
 	while ( defined(my $it = $elements->[++$position]) ) {
 		return $it if $it->significant;
 	}
@@ -304,12 +299,10 @@ C<PPI::Element> object.
 
 sub previous_sibling {
 	my $self     = shift;
-	my $parent   = $_PARENT{refaddr $self} or return '';
 	my $key      = refaddr $self;
+	my $parent   = $_PARENT{$key} or return '';
 	my $elements = $parent->{children};
-	my $position = List::Util::first {
-		refaddr $elements->[$_] == $key
-		} 0..$#$elements;
+	my $position = $parent->__position($self);
 	$position and $elements->[$position - 1] or '';
 }
 
@@ -327,12 +320,10 @@ sibling.
 
 sub sprevious_sibling {
 	my $self     = shift;
-	my $parent   = $_PARENT{refaddr $self} or return '';
 	my $key      = refaddr $self;
+	my $parent   = $_PARENT{$key} or return '';
 	my $elements = $parent->{children};
-	my $position = List::Util::first {
-		refaddr $elements->[$_] == $key
-		} 0..$#$elements;
+	my $position = $parent->__position($self);
 	while ( $position-- and defined(my $it = $elements->[$position]) ) {
 		return $it if $it->significant;
 	}
@@ -589,12 +580,14 @@ To prevent accidental damage to code, in this initial implementation the
 replacement element B<must> be of the same class (or a subclass) as the
 one being replaced.
 
+If successful, returns the replace element.  Otherwise, returns C<undef>.
+
 =cut
 
 sub replace {
 	my $self    = ref $_[0] ? shift : return undef;
-	_INSTANCE(shift, ref $self) or return undef;
-	die "The ->replace method has not yet been implemented";
+	my $replace = _INSTANCE(shift, ref $self) or return undef;
+	return $self->parent->replace_child( $self, $replace );
 }
 
 =pod
@@ -842,8 +835,10 @@ sub _clear {
 # ->delete means our reference count has probably fallen to zero.
 # Therefore we don't need to remove ourselves from our parent,
 # just the index ( just in case ).
-### XS -> PPI/XS.xs:_PPI_Element__DESTROY 0.900+
-sub DESTROY { delete $_PARENT{refaddr $_[0]} }
+sub DESTROY {
+  delete $_PARENT{refaddr $_[0]};
+  delete $_POSITION_CACHE{refaddr $_[0]};
+}
 
 # Operator overloads
 sub __equals  { ref $_[1] and refaddr($_[0]) == refaddr($_[1]) }
