@@ -59,15 +59,14 @@ parent L<PPI::Token> and L<PPI::Element> classes.
 =cut
 
 use strict;
-use base 'PPI::Token';
+use PPI::Token ();
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.203';
-}
+our $VERSION = '1.279';
+
+our @ISA = "PPI::Token";
 
 ### XS -> PPI/XS.xs:_PPI_Token_Comment__significant 0.900+
-sub significant { '' }
+sub significant() { '' }
 
 # Most stuff goes through __TOKENIZER__commit.
 # This is such a rare case, do char at a time to keep the code small
@@ -86,14 +85,14 @@ sub __TOKENIZER__commit {
 	my $t = $_[1];
 
 	# Get the rest of the line
-	my $rest_of_line = substr( $t->{line}, $t->{line_cursor} );
-	if ( chomp $rest_of_line) { # Include the newline separately
+	my $rest = substr( $t->{line}, $t->{line_cursor} );
+	if ( chomp $rest ) { # Include the newline separately
 		# Add the current token, and the newline
-		$t->_new_token('Comment', $rest_of_line);
+		$t->_new_token('Comment', $rest);
 		$t->_new_token('Whitespace', "\n");
 	} else {
 		# Add this token only
-		$t->_new_token('Comment', $rest_of_line);
+		$t->_new_token('Comment', $rest);
 	}
 
 	# Advance the line cursor to the end
@@ -136,7 +135,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2008 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
