@@ -28,18 +28,18 @@ There are no methods available for C<PPI::Token::Regexp::Substitute>
 beyond those provided by the parent L<PPI::Token::Regexp>, L<PPI::Token>
 and L<PPI::Element> classes.
 
-Got any ideas for methods? Submit a report to rt.cpan.org!
-
 =cut
 
 use strict;
-use base 'PPI::Token::_QuoteEngine::Full',
-         'PPI::Token::Regexp';
+use PPI::Token::Regexp             ();
+use PPI::Token::_QuoteEngine::Full ();
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.203';
-}
+our $VERSION = '1.279';
+
+our @ISA = qw{
+	PPI::Token::_QuoteEngine::Full
+	PPI::Token::Regexp
+};
 
 1;
 
@@ -55,7 +55,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2008 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
